"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation lists the provisioned capacity units for the specified AWS account.

    Args:
        account_id(str): The AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, don't include any hyphens ('-') in the ID. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.provisioned_capacity.list(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.provisioned_capacity.list account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="list_provisioned_capacity",
        op_kwargs={"accountId": account_id},
    )


async def purchase(hub, ctx, account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation purchases a provisioned capacity unit for an AWS account.

    Args:
        account_id(str): The AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, don't include any hyphens ('-') in the ID. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.provisioned_capacity.purchase(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.provisioned_capacity.purchase account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="purchase_provisioned_capacity",
        op_kwargs={"accountId": account_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, name: str, bot_name: str, bot_alias: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the association between an Amazon Lex bot and a messaging platform. This operation requires permission for the lex:DeleteBotChannelAssociation action.

    Args:
        name(str): The name of the association. The name is case sensitive. .
        bot_name(str): The name of the Amazon Lex bot.
        bot_alias(str): An alias that points to the specific version of the Amazon Lex bot to which this association is being made.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.bot.channel_association.delete(
                ctx, name=value, bot_name=value, bot_alias=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.bot.channel_association.delete name=value, bot_name=value, bot_alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="delete_bot_channel_association",
        op_kwargs={"name": name, "botName": bot_name, "botAlias": bot_alias},
    )


async def get(hub, ctx, name: str, bot_name: str, bot_alias: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the association between an Amazon Lex bot and a messaging platform. This operation requires permissions for the lex:GetBotChannelAssociation action.

    Args:
        name(str): The name of the association between the bot and the channel. The name is case sensitive. .
        bot_name(str): The name of the Amazon Lex bot.
        bot_alias(str): An alias pointing to the specific version of the Amazon Lex bot to which this association is being made.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.bot.channel_association.get(
                ctx, name=value, bot_name=value, bot_alias=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.bot.channel_association.get name=value, bot_name=value, bot_alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_bot_channel_association",
        op_kwargs={"name": name, "botName": bot_name, "botAlias": bot_alias},
    )


async def get_all(
    hub,
    ctx,
    bot_name: str,
    bot_alias: str,
    next_token: str = None,
    max_results: int = None,
    name_contains: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of all of the channels associated with the specified bot.  The GetBotChannelAssociations operation requires permissions for the lex:GetBotChannelAssociations action.

    Args:
        bot_name(str): The name of the Amazon Lex bot in the association.
        bot_alias(str): An alias pointing to the specific version of the Amazon Lex bot to which this association is being made.
        next_token(str, optional): A pagination token for fetching the next page of associations. If the response to this call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of associations, specify the pagination token in the next request. . Defaults to None.
        max_results(int, optional): The maximum number of associations to return in the response. The default is 50. . Defaults to None.
        name_contains(str, optional): Substring to match in channel association names. An association will be returned if any part of its name matches the substring. For example, "xyz" matches both "xyzabc" and "abcxyz." To return all bot channel associations, use a hyphen ("-") as the nameContains parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.bot.channel_association.get_all(
                ctx, bot_name=value, bot_alias=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.bot.channel_association.get_all bot_name=value, bot_alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_bot_channel_associations",
        op_kwargs={
            "botName": bot_name,
            "botAlias": bot_alias,
            "nextToken": next_token,
            "maxResults": max_results,
            "nameContains": name_contains,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource: str, tags: Dict) -> None:
    r"""
    **Autogenerated function**

    Adds tags to a function.

    Args:
        resource(str): The function's Amazon Resource Name (ARN).
        tags(Dict): A list of tags to apply to the function.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.resource.tag(ctx, resource=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.resource.tag resource=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="tag_resource",
        op_kwargs={"Resource": resource, "Tags": tags},
    )


async def untag(hub, ctx, resource: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes tags from a function.

    Args:
        resource(str): The function's Amazon Resource Name (ARN).
        tag_keys(List): A list of tag keys to remove from the function.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.resource.untag(ctx, resource=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.resource.untag resource=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="untag_resource",
        op_kwargs={"Resource": resource, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    subnet_id: str,
    allocation_id: str = None,
    client_token: str = None,
    dry_run: bool = None,
    tag_specifications: List = None,
    connectivity_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a NAT gateway in the specified subnet. This action creates a network interface in the specified subnet with a private IP address from the IP address range of the subnet. You can create either a public NAT gateway or a private NAT gateway. With a public NAT gateway, internet-bound traffic from a private subnet can be routed to the NAT gateway, so that instances in a private subnet can connect to the internet. With a private NAT gateway, private communication is routed across VPCs and on-premises networks through a transit gateway or virtual private gateway. Common use cases include running large workloads behind a small pool of allowlisted IPv4 addresses, preserving private IPv4 addresses, and communicating between overlapping networks. For more information, see NAT gateways in the Amazon Virtual Private Cloud User Guide.

    Args:
        allocation_id(str, optional): [Public NAT gateways only] The allocation ID of an Elastic IP address to associate with the NAT gateway. You cannot specify an Elastic IP address with a private NAT gateway. If the Elastic IP address is associated with another resource, you must first disassociate it. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency. Constraint: Maximum 64 ASCII characters. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        subnet_id(str): The subnet in which to create the NAT gateway.
        tag_specifications(List, optional): The tags to assign to the NAT gateway. Defaults to None.
        connectivity_type(str, optional): Indicates whether the NAT gateway supports public or private connectivity. The default is public connectivity. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.nat_gateway.create(ctx, subnet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.nat_gateway.create subnet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_nat_gateway",
        op_kwargs={
            "AllocationId": allocation_id,
            "ClientToken": client_token,
            "DryRun": dry_run,
            "SubnetId": subnet_id,
            "TagSpecifications": tag_specifications,
            "ConnectivityType": connectivity_type,
        },
    )


async def delete(hub, ctx, nat_gateway_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified NAT gateway. Deleting a public NAT gateway disassociates its Elastic IP address, but does not release the address from your account. Deleting a NAT gateway does not delete any NAT gateway routes in your route tables.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        nat_gateway_id(str): The ID of the NAT gateway.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.nat_gateway.delete(ctx, nat_gateway_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.nat_gateway.delete nat_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_nat_gateway",
        op_kwargs={"DryRun": dry_run, "NatGatewayId": nat_gateway_id},
    )


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    filter_: List = None,
    max_results: int = None,
    nat_gateway_ids: List = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your NAT gateways.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        filter_(List, optional): One or more filters.    nat-gateway-id - The ID of the NAT gateway.    state - The state of the NAT gateway (pending | failed | available | deleting | deleted).    subnet-id - The ID of the subnet in which the NAT gateway resides.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC in which the NAT gateway resides.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        nat_gateway_ids(List, optional): One or more NAT gateway IDs. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.nat_gateway.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.nat_gateway.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_nat_gateways",
        op_kwargs={
            "DryRun": dry_run,
            "Filter": filter_,
            "MaxResults": max_results,
            "NatGatewayIds": nat_gateway_ids,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, analysis_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves runtime information about a detector model analysis.  After AWS IoT Events starts analyzing your detector model, you have up to 24 hours to retrieve the analysis results.

    Args:
        analysis_id(str): The ID of the analysis result that you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.detector_model.analysis.init.describe(
                ctx, analysis_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.detector_model.analysis.init.describe analysis_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="describe_detector_model_analysis",
        op_kwargs={"analysisId": analysis_id},
    )


async def start(hub, ctx, detector_model_definition: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Performs an analysis of your detector model. For more information, see Troubleshooting a detector model in the AWS IoT Events Developer Guide.

    Args:
        detector_model_definition(Dict): Information that defines how a detector operates.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.detector_model.analysis.init.start(
                ctx, detector_model_definition=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.detector_model.analysis.init.start detector_model_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="start_detector_model_analysis",
        op_kwargs={"detectorModelDefinition": detector_model_definition},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(hub, ctx, skill_id: str, skill_group_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a skill from a skill group.

    Args:
        skill_group_arn(str, optional): The unique identifier of a skill. Required. Defaults to None.
        skill_id(str): The ARN of a skill group to associate to a skill.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.skill.from_.skill_group.disassociate(
                ctx, skill_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.skill.from_.skill_group.disassociate skill_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="disassociate_skill_from_skill_group",
        op_kwargs={"SkillGroupArn": skill_group_arn, "SkillId": skill_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_id: str, tag_list: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds or overwrites one or more tags for the specified AWS CloudHSM cluster.

    Args:
        resource_id(str): The cluster identifier (ID) for the cluster that you are tagging. To find the cluster ID, use DescribeClusters.
        tag_list(List): A list of one or more tags.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsmv2.resource.tag(ctx, resource_id=value, tag_list=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsmv2.resource.tag resource_id=value, tag_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsmv2",
        operation="tag_resource",
        op_kwargs={"ResourceId": resource_id, "TagList": tag_list},
    )


async def untag(hub, ctx, resource_id: str, tag_key_list: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified tag or tags from the specified AWS CloudHSM cluster.

    Args:
        resource_id(str): The cluster identifier (ID) for the cluster whose tags you are removing. To find the cluster ID, use DescribeClusters.
        tag_key_list(List): A list of one or more tag keys for the tags that you are removing. Specify only the tag keys, not the tag values.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsmv2.resource.untag(
                ctx, resource_id=value, tag_key_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsmv2.resource.untag resource_id=value, tag_key_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsmv2",
        operation="untag_resource",
        op_kwargs={"ResourceId": resource_id, "TagKeyList": tag_key_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, app_ids: List = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves summaries for all applications.

    Args:
        app_ids(List, optional): The unique application IDs. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. The default value is 100. To retrieve the remaining results, make another call with the returned NextToken value. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.apps.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.apps.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="list_apps",
        op_kwargs={
            "appIds": app_ids,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, import_destination: Dict, import_data_source: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates an import job for a data destination.

    Args:
        import_destination(Dict): The destination for the import job.
        import_data_source(Dict): The data source for the import job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.import_job.create(
                ctx, import_destination=value, import_data_source=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.import_job.create import_destination=value, import_data_source=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="create_import_job",
        op_kwargs={
            "ImportDestination": import_destination,
            "ImportDataSource": import_data_source,
        },
    )


async def get(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides information about an import job.

    Args:
        job_id(str): The ID of the import job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.import_job.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.import_job.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="get_import_job",
        op_kwargs={"JobId": job_id},
    )


async def list_all(
    hub,
    ctx,
    import_destination_type: str = None,
    next_token: str = None,
    page_size: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the import jobs.

    Args:
        import_destination_type(str, optional): The destination of the import job, which can be used to list import jobs that have a certain ImportDestinationType. Defaults to None.
        next_token(str, optional): A string token indicating that there might be additional import jobs available to be listed. Copy this token to a subsequent call to ListImportJobs with the same parameters to retrieve the next page of import jobs. Defaults to None.
        page_size(int, optional): Maximum number of import jobs to return at once. Use this parameter to paginate results. If additional import jobs exist beyond the specified limit, the NextToken element is sent in the response. Use the NextToken value in subsequent requests to retrieve additional addresses. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.import_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.import_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="list_import_jobs",
        op_kwargs={
            "ImportDestinationType": import_destination_type,
            "NextToken": next_token,
            "PageSize": page_size,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"import_": "import"}


async def create(
    hub,
    ctx,
    name: str,
    semantic_version: str,
    platform: str,
    client_token: str,
    description: str = None,
    change_description: str = None,
    supported_os_versions: List = None,
    data: str = None,
    uri: str = None,
    kms_key_id: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new component that can be used to build, validate, test, and assess your image.

    Args:
        name(str): The name of the component.
        semantic_version(str): The semantic version of the component. This version follows the semantic version syntax.  The semantic version has four nodes: <major>.<minor>.<patch>/<build>. You can assign values for the first three, and can filter on all of them.  Assignment: For the first three nodes you can assign any positive integer value, including zero, with an upper limit of 2^30-1, or 1073741823 for each node. Image Builder automatically assigns the build number, and that is not open for updates.  Patterns: You can use any numeric pattern that adheres to the assignment requirements for the nodes that you can assign. For example, you might choose a software version pattern, such as 1.0.0, or a date, such as 2021.01.01. .
        description(str, optional): The description of the component. Describes the contents of the component. Defaults to None.
        change_description(str, optional): The change description of the component. Describes what change has been made in this version, or what makes this version different from other versions of this component. Defaults to None.
        platform(str): The platform of the component.
        supported_os_versions(List, optional):  The operating system (OS) version supported by the component. If the OS information is available, a prefix match is performed against the parent image OS version during image recipe creation. Defaults to None.
        data(str, optional): The data of the component. Used to specify the data inline. Either data or uri can be used to specify the data within the component. Defaults to None.
        uri(str, optional): The uri of the component. Must be an Amazon S3 URL and the requester must have permission to access the Amazon S3 bucket. If you use Amazon S3, you can specify component content up to your service quota. Either data or uri can be used to specify the data within the component. Defaults to None.
        kms_key_id(str, optional): The ID of the KMS key that should be used to encrypt this component. Defaults to None.
        tags(Dict, optional): The tags of the component. Defaults to None.
        client_token(str): The idempotency token of the component.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.component.init.create(ctx, name=value, semantic_version=value, platform=value, client_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.component.init.create name=value, semantic_version=value, platform=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="create_component",
        op_kwargs={
            "name": name,
            "semanticVersion": semantic_version,
            "description": description,
            "changeDescription": change_description,
            "platform": platform,
            "supportedOsVersions": supported_os_versions,
            "data": data,
            "uri": uri,
            "kmsKeyId": kms_key_id,
            "tags": tags,
            "clientToken": client_token,
        },
    )


async def delete(hub, ctx, component_build_version_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a component build version.

    Args:
        component_build_version_arn(str): The Amazon Resource Name (ARN) of the component build version to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.component.init.delete(ctx, component_build_version_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.component.init.delete component_build_version_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="delete_component",
        op_kwargs={"componentBuildVersionArn": component_build_version_arn},
    )


async def get(hub, ctx, component_build_version_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Gets a component object.

    Args:
        component_build_version_arn(str): The Amazon Resource Name (ARN) of the component that you want to retrieve. Regex requires "/\d+$" suffix.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.component.init.get(ctx, component_build_version_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.component.init.get component_build_version_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="get_component",
        op_kwargs={"componentBuildVersionArn": component_build_version_arn},
    )


async def import_(
    hub,
    ctx,
    name: str,
    semantic_version: str,
    type_: str,
    format_: str,
    platform: str,
    client_token: str,
    description: str = None,
    change_description: str = None,
    data: str = None,
    uri: str = None,
    kms_key_id: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Imports a component and transforms its data into a component document.

    Args:
        name(str):  The name of the component.
        semantic_version(str): The semantic version of the component. This version follows the semantic version syntax.  The semantic version has four nodes: <major>.<minor>.<patch>/<build>. You can assign values for the first three, and can filter on all of them.  Filtering: When you retrieve or reference a resource with a semantic version, you can use wildcards (x) to filter your results. When you use a wildcard in any node, all nodes to the right of the first wildcard must also be wildcards. For example, specifying "1.2.x", or "1.x.x" works to filter list results, but neither "1.x.2", nor "x.2.x" will work. You do not have to specify the build - Image Builder automatically uses a wildcard for that, if applicable. .
        description(str, optional): The description of the component. Describes the contents of the component. Defaults to None.
        change_description(str, optional): The change description of the component. Describes what change has been made in this version, or what makes this version different from other versions of this component. Defaults to None.
        type_(str): The type of the component denotes whether the component is used to build the image, or only to test it.
        format_(str): The format of the resource that you want to import as a component.
        platform(str): The platform of the component.
        data(str, optional): The data of the component. Used to specify the data inline. Either data or uri can be used to specify the data within the component. Defaults to None.
        uri(str, optional): The uri of the component. Must be an Amazon S3 URL and the requester must have permission to access the Amazon S3 bucket. If you use Amazon S3, you can specify component content up to your service quota. Either data or uri can be used to specify the data within the component. Defaults to None.
        kms_key_id(str, optional): The ID of the KMS key that should be used to encrypt this component. Defaults to None.
        tags(Dict, optional): The tags of the component. Defaults to None.
        client_token(str): The idempotency token of the component.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.component.init.import(ctx, name=value, semantic_version=value, type_=value, format_=value, platform=value, client_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.component.init.import name=value, semantic_version=value, type_=value, format_=value, platform=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="import_component",
        op_kwargs={
            "name": name,
            "semanticVersion": semantic_version,
            "description": description,
            "changeDescription": change_description,
            "type": type_,
            "format": format_,
            "platform": platform,
            "data": data,
            "uri": uri,
            "kmsKeyId": kms_key_id,
            "tags": tags,
            "clientToken": client_token,
        },
    )


async def list_all(
    hub,
    ctx,
    owner: str = None,
    filters: List = None,
    by_name: bool = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the list of component build versions for the specified semantic version.  The semantic version has four nodes: <major>.<minor>.<patch>/<build>. You can assign values for the first three, and can filter on all of them.  Filtering: When you retrieve or reference a resource with a semantic version, you can use wildcards (x) to filter your results. When you use a wildcard in any node, all nodes to the right of the first wildcard must also be wildcards. For example, specifying "1.2.x", or "1.x.x" works to filter list results, but neither "1.x.2", nor "x.2.x" will work. You do not have to specify the build - Image Builder automatically uses a wildcard for that, if applicable.

    Args:
        owner(str, optional): The owner defines which components you want to list. By default, this request will only show components owned by your account. You can use this field to specify if you want to view components owned by yourself, by Amazon, or those components that have been shared with you by other customers. Defaults to None.
        filters(List, optional): The filters. Defaults to None.
        by_name(bool, optional): Returns the list of component build versions for the specified name. Defaults to None.
        max_results(int, optional): The maximum items to return in a request. Defaults to None.
        next_token(str, optional): A token to specify where to start paginating. This is the NextToken from a previously truncated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.component.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.component.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="list_components",
        op_kwargs={
            "owner": owner,
            "filters": filters,
            "byName": by_name,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def assume(
    hub,
    ctx,
    role_arn: str,
    role_session_name: str,
    web_identity_token: str,
    provider_id: str = None,
    policy_arns: List = None,
    policy: str = None,
    duration_seconds: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a set of temporary security credentials for users who have been authenticated in a mobile or web application with a web identity provider. Example providers include Amazon Cognito, Login with Amazon, Facebook, Google, or any OpenID Connect-compatible identity provider.  For mobile applications, we recommend that you use Amazon Cognito. You can use Amazon Cognito with the Amazon Web Services SDK for iOS Developer Guide and the Amazon Web Services SDK for Android Developer Guide to uniquely identify a user. You can also supply the user with a consistent identity throughout the lifetime of an application. To learn more about Amazon Cognito, see Amazon Cognito Overview in Amazon Web Services SDK for Android Developer Guide and Amazon Cognito Overview in the Amazon Web Services SDK for iOS Developer Guide.  Calling AssumeRoleWithWebIdentity does not require the use of Amazon Web Services security credentials. Therefore, you can distribute an application (for example, on mobile devices) that requests temporary security credentials without including long-term Amazon Web Services credentials in the application. You also don't need to deploy server-based proxy services that use long-term Amazon Web Services credentials. Instead, the identity of the caller is validated by using a token from the web identity provider. For a comparison of AssumeRoleWithWebIdentity with the other API operations that produce temporary credentials, see Requesting Temporary Security Credentials and Comparing the STS API operations in the IAM User Guide. The temporary security credentials returned by this API consist of an access key ID, a secret access key, and a security token. Applications can use these temporary security credentials to sign calls to Amazon Web Services service API operations.  Session Duration  By default, the temporary security credentials created by AssumeRoleWithWebIdentity last for one hour. However, you can use the optional DurationSeconds parameter to specify the duration of your session. You can provide a value from 900 seconds (15 minutes) up to the maximum session duration setting for the role. This setting can have a value from 1 hour to 12 hours. To learn how to view the maximum value for your role, see View the Maximum Session Duration Setting for a Role in the IAM User Guide. The maximum session duration limit applies when you use the AssumeRole* API operations or the assume-role* CLI commands. However the limit does not apply when you use those operations to create a console URL. For more information, see Using IAM Roles in the IAM User Guide.   Permissions  The temporary security credentials created by AssumeRoleWithWebIdentity can be used to make API calls to any Amazon Web Services service with the following exception: you cannot call the STS GetFederationToken or GetSessionToken API operations. (Optional) You can pass inline or managed session policies to this operation. You can pass a single JSON policy document to use as an inline session policy. You can also specify up to 10 managed policies to use as managed session policies. The plaintext that you use for both inline and managed session policies can't exceed 2,048 characters. Passing policies to this operation returns new temporary credentials. The resulting session's permissions are the intersection of the role's identity-based policy and the session policies. You can use the role's temporary credentials in subsequent Amazon Web Services API calls to access resources in the account that owns the role. You cannot use session policies to grant more permissions than those allowed by the identity-based policy of the role that is being assumed. For more information, see Session Policies in the IAM User Guide.  Tags  (Optional) You can configure your IdP to pass attributes into your web identity token as session tags. Each session tag consists of a key name and an associated value. For more information about session tags, see Passing Session Tags in STS in the IAM User Guide. You can pass up to 50 session tags. The plaintext session tag keys can’t exceed 128 characters and the values can’t exceed 256 characters. For these and additional limits, see IAM and STS Character Limits in the IAM User Guide.  An Amazon Web Services conversion compresses the passed session policies and session tags into a packed binary format that has a separate limit. Your request can fail for this limit even if your plaintext meets the other requirements. The PackedPolicySize response element indicates by percentage how close the policies and tags for your request are to the upper size limit.   You can pass a session tag with the same key as a tag that is attached to the role. When you do, the session tag overrides the role tag with the same key. An administrator must grant you the permissions necessary to pass session tags. The administrator can also create granular permissions to allow you to pass only specific session tags. For more information, see Tutorial: Using Tags for Attribute-Based Access Control in the IAM User Guide. You can set the session tags as transitive. Transitive tags persist during role chaining. For more information, see Chaining Roles with Session Tags in the IAM User Guide.  Identities  Before your application can call AssumeRoleWithWebIdentity, you must have an identity token from a supported identity provider and create a role that the application can assume. The role that your application assumes must trust the identity provider that is associated with the identity token. In other words, the identity provider must be specified in the role's trust policy.   Calling AssumeRoleWithWebIdentity can result in an entry in your CloudTrail logs. The entry includes the Subject of the provided web identity token. We recommend that you avoid using any personally identifiable information (PII) in this field. For example, you could instead use a GUID or a pairwise identifier, as suggested in the OIDC specification.  For more information about how to use web identity federation and the AssumeRoleWithWebIdentity API, see the following resources:     Using Web Identity Federation API Operations for Mobile Apps and Federation Through a Web-based Identity Provider.      Web Identity Federation Playground. Walk through the process of authenticating through Login with Amazon, Facebook, or Google, getting temporary security credentials, and then using those credentials to make a request to Amazon Web Services.     Amazon Web Services SDK for iOS Developer Guide and Amazon Web Services SDK for Android Developer Guide. These toolkits contain sample apps that show how to invoke the identity providers. The toolkits then show how to use the information from these providers to get and use temporary security credentials.     Web Identity Federation with Mobile Applications. This article discusses web identity federation and shows an example of how to use web identity federation to get access to content in Amazon S3.

    Args:
        role_arn(str): The Amazon Resource Name (ARN) of the role that the caller is assuming.
        role_session_name(str): An identifier for the assumed role session. Typically, you pass the name or identifier that is associated with the user who is using your application. That way, the temporary security credentials that your application will use are associated with that user. This session name is included as part of the ARN and assumed role ID in the AssumedRoleUser response element. The regex used to validate this parameter is a string of characters consisting of upper- and lower-case alphanumeric characters with no spaces. You can also include underscores or any of the following characters: =,.@-.
        web_identity_token(str): The OAuth 2.0 access token or OpenID Connect ID token that is provided by the identity provider. Your application must get this token by authenticating the user who is using your application with a web identity provider before the application makes an AssumeRoleWithWebIdentity call. .
        provider_id(str, optional): The fully qualified host component of the domain name of the identity provider. Specify this value only for OAuth 2.0 access tokens. Currently www.amazon.com and graph.facebook.com are the only supported identity providers for OAuth 2.0 access tokens. Do not include URL schemes and port numbers. Do not specify this value for OpenID Connect ID tokens. Defaults to None.
        policy_arns(List, optional): The Amazon Resource Names (ARNs) of the IAM managed policies that you want to use as managed session policies. The policies must exist in the same account as the role. This parameter is optional. You can provide up to 10 managed policy ARNs. However, the plaintext that you use for both inline and managed session policies can't exceed 2,048 characters. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.  An Amazon Web Services conversion compresses the passed session policies and session tags into a packed binary format that has a separate limit. Your request can fail for this limit even if your plaintext meets the other requirements. The PackedPolicySize response element indicates by percentage how close the policies and tags for your request are to the upper size limit.   Passing policies to this operation returns new temporary credentials. The resulting session's permissions are the intersection of the role's identity-based policy and the session policies. You can use the role's temporary credentials in subsequent Amazon Web Services API calls to access resources in the account that owns the role. You cannot use session policies to grant more permissions than those allowed by the identity-based policy of the role that is being assumed. For more information, see Session Policies in the IAM User Guide. Defaults to None.
        policy(str, optional): An IAM policy in JSON format that you want to use as an inline session policy. This parameter is optional. Passing policies to this operation returns new temporary credentials. The resulting session's permissions are the intersection of the role's identity-based policy and the session policies. You can use the role's temporary credentials in subsequent Amazon Web Services API calls to access resources in the account that owns the role. You cannot use session policies to grant more permissions than those allowed by the identity-based policy of the role that is being assumed. For more information, see Session Policies in the IAM User Guide. The plaintext that you use for both inline and managed session policies can't exceed 2,048 characters. The JSON policy characters can be any ASCII character from the space character to the end of the valid character list (\u0020 through \u00FF). It can also include the tab (\u0009), linefeed (\u000A), and carriage return (\u000D) characters.  An Amazon Web Services conversion compresses the passed session policies and session tags into a packed binary format that has a separate limit. Your request can fail for this limit even if your plaintext meets the other requirements. The PackedPolicySize response element indicates by percentage how close the policies and tags for your request are to the upper size limit.  . Defaults to None.
        duration_seconds(int, optional): The duration, in seconds, of the role session. The value can range from 900 seconds (15 minutes) up to the maximum session duration setting for the role. This setting can have a value from 1 hour to 12 hours. If you specify a value higher than this setting, the operation fails. For example, if you specify a session duration of 12 hours, but your administrator set the maximum session duration to 6 hours, your operation fails. To learn how to view the maximum value for your role, see View the Maximum Session Duration Setting for a Role in the IAM User Guide. By default, the value is set to 3600 seconds.   The DurationSeconds parameter is separate from the duration of a console session that you might request using the returned credentials. The request to the federation endpoint for a console sign-in token takes a SessionDuration parameter that specifies the maximum length of the console session. For more information, see Creating a URL that Enables Federated Users to Access the Management Console in the IAM User Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sts.role.with_.web_identity.assume(
                ctx, role_arn=value, role_session_name=value, web_identity_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sts.role.with_.web_identity.assume role_arn=value, role_session_name=value, web_identity_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sts",
        operation="assume_role_with_web_identity",
        op_kwargs={
            "RoleArn": role_arn,
            "RoleSessionName": role_session_name,
            "WebIdentityToken": web_identity_token,
            "ProviderId": provider_id,
            "PolicyArns": policy_arns,
            "Policy": policy,
            "DurationSeconds": duration_seconds,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub, ctx, network_interface_id: str, attribute: str = None, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes a network interface attribute. You can specify only one attribute at a time.

    Args:
        attribute(str, optional): The attribute of the network interface. This parameter is required. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        network_interface_id(str): The ID of the network interface.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.interface.attribute.describe(
                ctx, network_interface_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.interface.attribute.describe network_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_network_interface_attribute",
        op_kwargs={
            "Attribute": attribute,
            "DryRun": dry_run,
            "NetworkInterfaceId": network_interface_id,
        },
    )


async def modify(
    hub,
    ctx,
    network_interface_id: str,
    attachment: Dict = None,
    description: Dict = None,
    dry_run: bool = None,
    groups: List = None,
    source_dest_check: Dict = None,
) -> None:
    r"""
    **Autogenerated function**

    Modifies the specified network interface attribute. You can specify only one attribute at a time. You can use this action to attach and detach security groups from an existing EC2 instance.

    Args:
        attachment(Dict, optional): Information about the interface attachment. If modifying the 'delete on termination' attribute, you must specify the ID of the interface attachment. Defaults to None.
        description(Dict, optional): A description for the network interface. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        groups(List, optional): Changes the security groups for the network interface. The new set of groups you specify replaces the current set. You must specify at least one group, even if it's just the default security group in the VPC. You must specify the ID of the security group, not the name. Defaults to None.
        network_interface_id(str): The ID of the network interface.
        source_dest_check(Dict, optional): Enable or disable source/destination checks, which ensure that the instance is either the source or the destination of any traffic that it receives. If the value is true, source/destination checks are enabled; otherwise, they are disabled. The default value is true. You must disable source/destination checks if the instance runs services such as network address translation, routing, or firewalls. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.interface.attribute.modify(
                ctx, network_interface_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.interface.attribute.modify network_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_network_interface_attribute",
        op_kwargs={
            "Attachment": attachment,
            "Description": description,
            "DryRun": dry_run,
            "Groups": groups,
            "NetworkInterfaceId": network_interface_id,
            "SourceDestCheck": source_dest_check,
        },
    )


async def reset(
    hub,
    ctx,
    network_interface_id: str,
    dry_run: bool = None,
    source_dest_check: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Resets a network interface attribute. You can specify only one attribute at a time.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        network_interface_id(str): The ID of the network interface.
        source_dest_check(str, optional): The source/destination checking attribute. Resets the value to true. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.interface.attribute.reset(
                ctx, network_interface_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.interface.attribute.reset network_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="reset_network_interface_attribute",
        op_kwargs={
            "DryRun": dry_run,
            "NetworkInterfaceId": network_interface_id,
            "SourceDestCheck": source_dest_check,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, query_execution_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns the details of a single query execution or a list of up to 50 query executions, which you provide as an array of query execution ID strings. Requires you to have access to the workgroup in which the queries ran. To get a list of query execution IDs, use ListQueryExecutionsInput$WorkGroup. Query executions differ from named (saved) queries. Use BatchGetNamedQueryInput to get details about named queries.

    Args:
        query_execution_ids(List): An array of query execution IDs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.get.query_execution.batch(ctx, query_execution_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.get.query_execution.batch query_execution_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="batch_get_query_execution",
        op_kwargs={"QueryExecutionIds": query_execution_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, email_identity: str, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Verifies an email identity for use with Amazon Pinpoint. In Amazon Pinpoint, an identity is an email address or domain that you use when you send email. Before you can use an identity to send email with Amazon Pinpoint, you first have to verify it. By verifying an address, you demonstrate that you're the owner of the address, and that you've given Amazon Pinpoint permission to send email from the address. When you verify an email address, Amazon Pinpoint sends an email to the address. Your email address is verified as soon as you follow the link in the verification email.  When you verify a domain, this operation provides a set of DKIM tokens, which you can convert into CNAME tokens. You add these CNAME tokens to the DNS configuration for your domain. Your domain is verified when Amazon Pinpoint detects these records in the DNS configuration for your domain. It usually takes around 72 hours to complete the domain verification process.

    Args:
        email_identity(str): The email address or domain that you want to verify.
        tags(List, optional): An array of objects that define the tags (keys and values) that you want to associate with the email identity. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.email.identity.init.create(
                ctx, email_identity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.email.identity.init.create email_identity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="create_email_identity",
        op_kwargs={"EmailIdentity": email_identity, "Tags": tags},
    )


async def delete(hub, ctx, email_identity: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an email identity that you previously verified for use with Amazon Pinpoint. An identity can be either an email address or a domain name.

    Args:
        email_identity(str): The identity (that is, the email address or domain) that you want to delete from your Amazon Pinpoint account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.email.identity.init.delete(
                ctx, email_identity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.email.identity.init.delete email_identity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="delete_email_identity",
        op_kwargs={"EmailIdentity": email_identity},
    )


async def get(hub, ctx, email_identity: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides information about a specific identity associated with your Amazon Pinpoint account, including the identity's verification status, its DKIM authentication status, and its custom Mail-From settings.

    Args:
        email_identity(str): The email identity that you want to retrieve details for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.email.identity.init.get(
                ctx, email_identity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.email.identity.init.get email_identity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="get_email_identity",
        op_kwargs={"EmailIdentity": email_identity},
    )


async def list_all(hub, ctx, next_token: str = None, page_size: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all of the email identities that are associated with your Amazon Pinpoint account. An identity can be either an email address or a domain. This operation returns identities that are verified as well as those that aren't.

    Args:
        next_token(str, optional): A token returned from a previous call to ListEmailIdentities to indicate the position in the list of identities. Defaults to None.
        page_size(int, optional): The number of results to show in a single call to ListEmailIdentities. If the number of results is larger than the number you specified in this parameter, then the response includes a NextToken element, which you can use to obtain additional results. The value you specify has to be at least 0, and can be no more than 1000. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.email.identity.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.email.identity.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="list_email_identities",
        op_kwargs={"NextToken": next_token, "PageSize": page_size},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def admin(
    hub, ctx, user_pool_id: str, destination_user: Dict, source_user: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Links an existing user account in a user pool (DestinationUser) to an identity from an external identity provider (SourceUser) based on a specified attribute name and value from the external identity provider. This allows you to create a link from the existing user account to an external federated user identity that has not yet been used to sign in, so that the federated user identity can be used to sign in as the existing user account.   For example, if there is an existing user with a username and password, this API links that user to a federated user identity, so that when the federated user identity is used, the user signs in as the existing user account.   The maximum number of federated identities linked to a user is 5.   Because this API allows a user with an external federated identity to sign in as an existing user in the user pool, it is critical that it only be used with external identity providers and provider attributes that have been trusted by the application owner.  This action is enabled only for admin access and requires developer credentials.

    Args:
        user_pool_id(str): The user pool ID for the user pool.
        destination_user(Dict): The existing user in the user pool to be linked to the external identity provider user account. Can be a native (Username + Password) Cognito User Pools user or a federated user (for example, a SAML or Facebook user). If the user doesn't exist, an exception is thrown. This is the user that is returned when the new user (with the linked identity provider attribute) signs in. For a native username + password user, the ProviderAttributeValue for the DestinationUser should be the username in the user pool. For a federated user, it should be the provider-specific user_id. The ProviderAttributeName of the DestinationUser is ignored. The ProviderName should be set to Cognito for users in Cognito user pools.
        source_user(Dict): An external identity provider account for a user who does not currently exist yet in the user pool. This user must be a federated user (for example, a SAML or Facebook user), not another native user. If the SourceUser is a federated social identity provider user (Facebook, Google, or Login with Amazon), you must set the ProviderAttributeName to Cognito_Subject. For social identity providers, the ProviderName will be Facebook, Google, or LoginWithAmazon, and Cognito will automatically parse the Facebook, Google, and Login with Amazon tokens for id, sub, and user_id, respectively. The ProviderAttributeValue for the user must be the same value as the id, sub, or user_id value found in the social identity provider token.  For SAML, the ProviderAttributeName can be any value that matches a claim in the SAML assertion. If you wish to link SAML users based on the subject of the SAML assertion, you should map the subject to a claim through the SAML identity provider and submit that claim name as the ProviderAttributeName. If you set ProviderAttributeName to Cognito_Subject, Cognito will automatically parse the default unique identifier found in the subject from the SAML token.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.link_provider_for_user.admin(
                ctx, user_pool_id=value, destination_user=value, source_user=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.link_provider_for_user.admin user_pool_id=value, destination_user=value, source_user=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="admin_link_provider_for_user",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "DestinationUser": destination_user,
            "SourceUser": source_user,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    caller_reference: str,
    vpc: Dict = None,
    hosted_zone_config: Dict = None,
    delegation_set_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new public or private hosted zone. You create records in a public hosted zone to define how you want to route traffic on the internet for a domain, such as example.com, and its subdomains (apex.example.com, acme.example.com). You create records in a private hosted zone to define how you want to route traffic for a domain and its subdomains within one or more Amazon Virtual Private Clouds (Amazon VPCs).   You can't convert a public hosted zone to a private hosted zone or vice versa. Instead, you must create a new hosted zone with the same name and create new resource record sets.  For more information about charges for hosted zones, see Amazon Route 53 Pricing. Note the following:   You can't create a hosted zone for a top-level domain (TLD) such as .com.   For public hosted zones, Route 53 automatically creates a default SOA record and four NS records for the zone. For more information about SOA and NS records, see NS and SOA Records that Route 53 Creates for a Hosted Zone in the Amazon Route 53 Developer Guide. If you want to use the same name servers for multiple public hosted zones, you can optionally associate a reusable delegation set with the hosted zone. See the DelegationSetId element.   If your domain is registered with a registrar other than Route 53, you must update the name servers with your registrar to make Route 53 the DNS service for the domain. For more information, see Migrating DNS Service for an Existing Domain to Amazon Route 53 in the Amazon Route 53 Developer Guide.    When you submit a CreateHostedZone request, the initial status of the hosted zone is PENDING. For public hosted zones, this means that the NS and SOA records are not yet available on all Route 53 DNS servers. When the NS and SOA records are available, the status of the zone changes to INSYNC. The CreateHostedZone request requires the caller to have an ec2:DescribeVpcs permission.

    Args:
        name(str): The name of the domain. Specify a fully qualified domain name, for example, www.example.com. The trailing dot is optional; Amazon Route 53 assumes that the domain name is fully qualified. This means that Route 53 treats www.example.com (without a trailing dot) and www.example.com. (with a trailing dot) as identical. If you're creating a public hosted zone, this is the name you have registered with your DNS registrar. If your domain name is registered with a registrar other than Route 53, change the name servers for your domain to the set of NameServers that CreateHostedZone returns in DelegationSet.
        vpc(Dict, optional): (Private hosted zones only) A complex type that contains information about the Amazon VPC that you're associating with this hosted zone. You can specify only one Amazon VPC when you create a private hosted zone. To associate additional Amazon VPCs with the hosted zone, use AssociateVPCWithHostedZone after you create a hosted zone. Defaults to None.
        caller_reference(str): A unique string that identifies the request and that allows failed CreateHostedZone requests to be retried without the risk of executing the operation twice. You must use a unique CallerReference string every time you submit a CreateHostedZone request. CallerReference can be any unique string, for example, a date/time stamp.
        hosted_zone_config(Dict, optional): (Optional) A complex type that contains the following optional values:   For public and private hosted zones, an optional comment   For private hosted zones, an optional PrivateZone element   If you don't specify a comment or the PrivateZone element, omit HostedZoneConfig and the other elements. Defaults to None.
        delegation_set_id(str, optional): If you want to associate a reusable delegation set with this hosted zone, the ID that Amazon Route 53 assigned to the reusable delegation set when you created it. For more information about reusable delegation sets, see CreateReusableDelegationSet. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.hosted_zone.init.create(
                ctx, name=value, caller_reference=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.hosted_zone.init.create name=value, caller_reference=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="create_hosted_zone",
        op_kwargs={
            "Name": name,
            "VPC": vpc,
            "CallerReference": caller_reference,
            "HostedZoneConfig": hosted_zone_config,
            "DelegationSetId": delegation_set_id,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a hosted zone. If the hosted zone was created by another service, such as Cloud Map, see Deleting Public Hosted Zones That Were Created by Another Service in the Amazon Route 53 Developer Guide for information about how to delete it. (The process is the same for public and private hosted zones that were created by another service.) If you want to keep your domain registration but you want to stop routing internet traffic to your website or web application, we recommend that you delete resource record sets in the hosted zone instead of deleting the hosted zone.  If you delete a hosted zone, you can't undelete it. You must create a new hosted zone and update the name servers for your domain registration, which can require up to 48 hours to take effect. (If you delegated responsibility for a subdomain to a hosted zone and you delete the child hosted zone, you must update the name servers in the parent hosted zone.) In addition, if you delete a hosted zone, someone could hijack the domain and route traffic to their own resources using your domain name.  If you want to avoid the monthly charge for the hosted zone, you can transfer DNS service for the domain to a free DNS service. When you transfer DNS service, you have to update the name servers for the domain registration. If the domain is registered with Route 53, see UpdateDomainNameservers for information about how to replace Route 53 name servers with name servers for the new DNS service. If the domain is registered with another registrar, use the method provided by the registrar to update name servers for the domain registration. For more information, perform an internet search on "free DNS service." You can delete a hosted zone only if it contains only the default SOA record and NS resource record sets. If the hosted zone contains other resource record sets, you must delete them before you can delete the hosted zone. If you try to delete a hosted zone that contains other resource record sets, the request fails, and Route 53 returns a HostedZoneNotEmpty error. For information about deleting records from your hosted zone, see ChangeResourceRecordSets. To verify that the hosted zone has been deleted, do one of the following:   Use the GetHostedZone action to request information about the hosted zone.   Use the ListHostedZones action to get a list of the hosted zones associated with the current account.

    Args:
        id_(str): The ID of the hosted zone you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.hosted_zone.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.hosted_zone.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="delete_hosted_zone",
        op_kwargs={"Id": id_},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a specified hosted zone including the four name servers assigned to the hosted zone.

    Args:
        id_(str): The ID of the hosted zone that you want to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.hosted_zone.init.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.hosted_zone.init.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="route53", operation="get_hosted_zone", op_kwargs={"Id": id_}
    )


async def list_all(
    hub, ctx, marker: str = None, max_items: str = None, delegation_set_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of the public and private hosted zones that are associated with the current account. The response includes a HostedZones child element for each hosted zone. Amazon Route 53 returns a maximum of 100 items in each response. If you have a lot of hosted zones, you can use the maxitems parameter to list them in groups of up to 100.

    Args:
        marker(str, optional): If the value of IsTruncated in the previous response was true, you have more hosted zones. To get more hosted zones, submit another ListHostedZones request.  For the value of marker, specify the value of NextMarker from the previous response, which is the ID of the first hosted zone that Amazon Route 53 will return if you submit another request. If the value of IsTruncated in the previous response was false, there are no more hosted zones to get. Defaults to None.
        max_items(str, optional): (Optional) The maximum number of hosted zones that you want Amazon Route 53 to return. If you have more than maxitems hosted zones, the value of IsTruncated in the response is true, and the value of NextMarker is the hosted zone ID of the first hosted zone that Route 53 will return if you submit another request. Defaults to None.
        delegation_set_id(str, optional): If you're using reusable delegation sets and you want to list all of the hosted zones that are associated with a reusable delegation set, specify the ID of that reusable delegation set. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.hosted_zone.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.hosted_zone.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="list_hosted_zones",
        op_kwargs={
            "Marker": marker,
            "MaxItems": max_items,
            "DelegationSetId": delegation_set_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    forecast_name: str,
    predictor_arn: str,
    forecast_types: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a forecast for each item in the TARGET_TIME_SERIES dataset that was used to train the predictor. This is known as inference. To retrieve the forecast for a single item at low latency, use the operation. To export the complete forecast into your Amazon Simple Storage Service (Amazon S3) bucket, use the CreateForecastExportJob operation. The range of the forecast is determined by the ForecastHorizon value, which you specify in the CreatePredictor request. When you query a forecast, you can request a specific date range within the forecast. To get a list of all your forecasts, use the ListForecasts operation.  The forecasts generated by Amazon Forecast are in the same time zone as the dataset that was used to create the predictor.  For more information, see howitworks-forecast.  The Status of the forecast must be ACTIVE before you can query or export the forecast. Use the DescribeForecast operation to get the status.

    Args:
        forecast_name(str): A name for the forecast.
        predictor_arn(str): The Amazon Resource Name (ARN) of the predictor to use to generate the forecast.
        forecast_types(List, optional): The quantiles at which probabilistic forecasts are generated. You can currently specify up to 5 quantiles per forecast. Accepted values include 0.01 to 0.99 (increments of .01 only) and mean. The mean forecast is different from the median (0.50) when the distribution is not symmetric (for example, Beta and Negative Binomial). The default value is ["0.1", "0.5", "0.9"]. Defaults to None.
        tags(List, optional): The optional metadata that you apply to the forecast to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. The following basic restrictions apply to tags:   Maximum number of tags per resource - 50.   For each resource, each tag key must be unique, and each tag key can have only one value.   Maximum key length - 128 Unicode characters in UTF-8.   Maximum value length - 256 Unicode characters in UTF-8.   If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.   Tag keys and values are case sensitive.   Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Forecast considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.forecast.init.create(
                ctx, forecast_name=value, predictor_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.forecast.init.create forecast_name=value, predictor_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="create_forecast",
        op_kwargs={
            "ForecastName": forecast_name,
            "PredictorArn": predictor_arn,
            "ForecastTypes": forecast_types,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, forecast_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a forecast created using the CreateForecast operation. You can delete only forecasts that have a status of ACTIVE or CREATE_FAILED. To get the status, use the DescribeForecast operation. You can't delete a forecast while it is being exported. After a forecast is deleted, you can no longer query the forecast.

    Args:
        forecast_arn(str): The Amazon Resource Name (ARN) of the forecast to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.forecast.init.delete(ctx, forecast_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.forecast.init.delete forecast_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="delete_forecast",
        op_kwargs={"ForecastArn": forecast_arn},
    )


async def describe(hub, ctx, forecast_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a forecast created using the CreateForecast operation. In addition to listing the properties provided in the CreateForecast request, this operation lists the following properties:    DatasetGroupArn - The dataset group that provided the training data.    CreationTime     LastModificationTime     Status     Message - If an error occurred, information about the error.

    Args:
        forecast_arn(str): The Amazon Resource Name (ARN) of the forecast.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.forecast.init.describe(ctx, forecast_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.forecast.init.describe forecast_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="describe_forecast",
        op_kwargs={"ForecastArn": forecast_arn},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of forecasts created using the CreateForecast operation. For each forecast, this operation returns a summary of its properties, including its Amazon Resource Name (ARN). To retrieve the complete set of properties, specify the ARN with the DescribeForecast operation. You can filter the list using an array of Filter objects.

    Args:
        next_token(str, optional): If the result of the previous request was truncated, the response includes a NextToken. To retrieve the next set of results, use the token in the next request. Tokens expire after 24 hours. Defaults to None.
        max_results(int, optional): The number of items to return in the response. Defaults to None.
        filters(List, optional): An array of filters. For each filter, you provide a condition and a match statement. The condition is either IS or IS_NOT, which specifies whether to include or exclude the forecasts that match the statement from the list, respectively. The match statement consists of a key and a value.  Filter properties     Condition - The condition to apply. Valid values are IS and IS_NOT. To include the forecasts that match the statement, specify IS. To exclude matching forecasts, specify IS_NOT.    Key - The name of the parameter to filter on. Valid values are DatasetGroupArn, PredictorArn, and Status.    Value - The value to match.   For example, to list all forecasts whose status is not ACTIVE, you would specify:  "Filters": [ { "Condition": "IS_NOT", "Key": "Status", "Value": "ACTIVE" } ] . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.forecast.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.forecast.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="list_forecasts",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, policy_id: str, member_account: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns detailed compliance information about the specified member account. Details include resources that are in and out of compliance with the specified policy.    Resources are considered noncompliant for WAF and Shield Advanced policies if the specified policy has not been applied to them.   Resources are considered noncompliant for security group policies if they are in scope of the policy, they violate one or more of the policy rules, and remediation is disabled or not possible.   Resources are considered noncompliant for Network Firewall policies if a firewall is missing in the VPC, if the firewall endpoint isn't set up in an expected Availability Zone and subnet, if a subnet created by the Firewall Manager doesn't have the expected route table, and for modifications to a firewall policy that violate the Firewall Manager policy's rules.   Resources are considered noncompliant for DNS Firewall policies if a DNS Firewall rule group is missing from the rule group associations for the VPC.

    Args:
        policy_id(str): The ID of the policy that you want to get the details for. PolicyId is returned by PutPolicy and by ListPolicies.
        member_account(str): The Amazon Web Services account that owns the resources that you want to get the details for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.compliance.detail.get(
                ctx, policy_id=value, member_account=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.compliance.detail.get policy_id=value, member_account=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fms",
        operation="get_compliance_detail",
        op_kwargs={"PolicyId": policy_id, "MemberAccount": member_account},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put_multiple(
    hub,
    ctx,
    configuration_set_name: str,
    tls_policy: str = None,
    sending_pool_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associate a configuration set with a dedicated IP pool. You can use dedicated IP pools to create groups of dedicated IP addresses for sending specific types of email.

    Args:
        configuration_set_name(str): The name of the configuration set that you want to associate with a dedicated IP pool.
        tls_policy(str, optional): Specifies whether messages that use the configuration set are required to use Transport Layer Security (TLS). If the value is Require, messages are only delivered if a TLS connection can be established. If the value is Optional, messages can be delivered in plain text if a TLS connection can't be established. Defaults to None.
        sending_pool_name(str, optional): The name of the dedicated IP pool that you want to associate with the configuration set. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.configuration_set_.delivery_option.put_multiple(
                ctx, configuration_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.configuration_set_.delivery_option.put_multiple configuration_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="put_configuration_set_delivery_options",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "TlsPolicy": tls_policy,
            "SendingPoolName": sending_pool_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, key: str, value: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a TagOption.

    Args:
        key(str): The TagOption key.
        value(str): The TagOption value.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.tag_option.init.create(
                ctx, key=value, value=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.tag_option.init.create key=value, value=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="create_tag_option",
        op_kwargs={"Key": key, "Value": value},
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified TagOption. You cannot delete a TagOption if it is associated with a product or portfolio.

    Args:
        id_(str): The TagOption identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.tag_option.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.tag_option.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="delete_tag_option",
        op_kwargs={"Id": id_},
    )


async def describe(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified TagOption.

    Args:
        id_(str): The TagOption identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.tag_option.init.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.tag_option.init.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_tag_option",
        op_kwargs={"Id": id_},
    )


async def list_all(
    hub, ctx, filters: Dict = None, page_size: int = None, page_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the specified TagOptions or all TagOptions.

    Args:
        filters(Dict, optional): The search filters. If no search filters are specified, the output includes all TagOptions. Defaults to None.
        page_size(int, optional): The maximum number of items to return with this call. Defaults to None.
        page_token(str, optional): The page token for the next set of results. To retrieve the first set of results, use null. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.tag_option.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.tag_option.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="list_tag_options",
        op_kwargs={"Filters": filters, "PageSize": page_size, "PageToken": page_token},
    )


async def update(hub, ctx, id_: str, value: str = None, active: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified TagOption.

    Args:
        id_(str): The TagOption identifier.
        value(str, optional): The updated value. Defaults to None.
        active(bool, optional): The updated active state. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.tag_option.init.update(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.tag_option.init.update id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="update_tag_option",
        op_kwargs={"Id": id_, "Value": value, "Active": active},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, service_code: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the default values for the quotas for the specified AWS service. A default value does not reflect any quota increases.

    Args:
        service_code(str): The service identifier.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, if any, make another call with the token returned from this call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.service_quotas.aws_default_service_quotas.list(
                ctx, service_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.service_quotas.aws_default_service_quotas.list service_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="service-quotas",
        operation="list_aws_default_service_quotas",
        op_kwargs={
            "ServiceCode": service_code,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, campaign_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve all the deliverability data for a specific campaign. This data is available for a campaign only if the campaign sent email by using a domain that the Deliverability dashboard is enabled for (PutDeliverabilityDashboardOption operation).

    Args:
        campaign_id(str): The unique identifier for the campaign. Amazon Pinpoint automatically generates and assigns this identifier to a campaign. This value is not the same as the campaign identifier that Amazon Pinpoint assigns to campaigns that you create and manage by using the Amazon Pinpoint API or the Amazon Pinpoint console.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.domain.deliverability_campaign.get(
                ctx, campaign_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.domain.deliverability_campaign.get campaign_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="get_domain_deliverability_campaign",
        op_kwargs={"CampaignId": campaign_id},
    )


async def list_all(
    hub,
    ctx,
    start_date: str,
    end_date: str,
    subscribed_domain: str,
    next_token: str = None,
    page_size: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve deliverability data for all the campaigns that used a specific domain to send email during a specified time range. This data is available for a domain only if you enabled the Deliverability dashboard (PutDeliverabilityDashboardOption operation) for the domain.

    Args:
        start_date(str): The first day, in Unix time format, that you want to obtain deliverability data for.
        end_date(str): The last day, in Unix time format, that you want to obtain deliverability data for. This value has to be less than or equal to 30 days after the value of the StartDate parameter.
        subscribed_domain(str): The domain to obtain deliverability data for.
        next_token(str, optional): A token that’s returned from a previous call to the ListDomainDeliverabilityCampaigns operation. This token indicates the position of a campaign in the list of campaigns. Defaults to None.
        page_size(int, optional): The maximum number of results to include in response to a single call to the ListDomainDeliverabilityCampaigns operation. If the number of results is larger than the number that you specify in this parameter, the response includes a NextToken element, which you can use to obtain additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.domain.deliverability_campaign.list_all(
                ctx, start_date=value, end_date=value, subscribed_domain=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.domain.deliverability_campaign.list_all start_date=value, end_date=value, subscribed_domain=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="list_domain_deliverability_campaigns",
        op_kwargs={
            "StartDate": start_date,
            "EndDate": end_date,
            "SubscribedDomain": subscribed_domain,
            "NextToken": next_token,
            "PageSize": page_size,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the access status of your account to the EC2 serial console of all instances. By default, access to the EC2 serial console is disabled for your account. For more information, see Manage account access to the EC2 serial console in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.serial_console_access.status.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.serial_console_access.status.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_serial_console_access_status",
        op_kwargs={"DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def apply(
    hub,
    ctx,
    client_vpn_endpoint_id: str,
    vpc_id: str,
    security_group_ids: List,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Applies a security group to the association between the target network and the Client VPN endpoint. This action replaces the existing security groups with the specified security groups.

    Args:
        client_vpn_endpoint_id(str): The ID of the Client VPN endpoint.
        vpc_id(str): The ID of the VPC in which the associated target network is located.
        security_group_ids(List): The IDs of the security groups to apply to the associated target network. Up to 5 security groups can be applied to an associated target network.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.security_group.to_client_vpn_target_network.apply(
                ctx, client_vpn_endpoint_id=value, vpc_id=value, security_group_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.security_group.to_client_vpn_target_network.apply client_vpn_endpoint_id=value, vpc_id=value, security_group_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="apply_security_groups_to_client_vpn_target_network",
        op_kwargs={
            "ClientVpnEndpointId": client_vpn_endpoint_id,
            "VpcId": vpc_id,
            "SecurityGroupIds": security_group_ids,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, window_execution_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops a maintenance window execution that is already in progress and cancels any tasks in the window that haven't already starting running. Tasks already in progress will continue to completion.

    Args:
        window_execution_id(str): The ID of the maintenance window execution to stop.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.maintenance_window.execution.init.cancel(
                ctx, window_execution_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.maintenance_window.execution.init.cancel window_execution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="cancel_maintenance_window_execution",
        op_kwargs={"WindowExecutionId": window_execution_id},
    )


async def describe_all(
    hub,
    ctx,
    window_id: str,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the executions of a maintenance window. This includes information about when the maintenance window was scheduled to be active, and information about tasks registered and run with the maintenance window.

    Args:
        window_id(str): The ID of the maintenance window whose executions should be retrieved.
        filters(List, optional): Each entry in the array is a structure containing:   Key. A string between 1 and 128 characters. Supported keys include ExecutedBefore and ExecutedAfter.   Values. An array of strings, each between 1 and 256 characters. Supported values are date/time strings in a valid ISO 8601 date/time format, such as 2021-11-04T05:00:00Z.  . Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.maintenance_window.execution.init.describe_all(
                ctx, window_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.maintenance_window.execution.init.describe_all window_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_maintenance_window_executions",
        op_kwargs={
            "WindowId": window_id,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def get(hub, ctx, window_execution_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves details about a specific a maintenance window execution.

    Args:
        window_execution_id(str): The ID of the maintenance window execution that includes the task.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.maintenance_window.execution.init.get(
                ctx, window_execution_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.maintenance_window.execution.init.get window_execution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_maintenance_window_execution",
        op_kwargs={"WindowExecutionId": window_execution_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    allowed_publishers: Dict,
    description: str = None,
    code_signing_policies: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a code signing configuration. A code signing configuration defines a list of allowed signing profiles and defines the code-signing validation policy (action to be taken if deployment validation checks fail).

    Args:
        description(str, optional): Descriptive name for this code signing configuration. Defaults to None.
        allowed_publishers(Dict): Signing profiles for this code signing configuration.
        code_signing_policies(Dict, optional): The code signing policies define the actions to take if the validation checks fail. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.code_signing_config.create(
                ctx, allowed_publishers=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.code_signing_config.create allowed_publishers=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="create_code_signing_config",
        op_kwargs={
            "Description": description,
            "AllowedPublishers": allowed_publishers,
            "CodeSigningPolicies": code_signing_policies,
        },
    )


async def delete(hub, ctx, code_signing_config_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the code signing configuration. You can delete the code signing configuration only if no function is using it.

    Args:
        code_signing_config_arn(str): The The Amazon Resource Name (ARN) of the code signing configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.code_signing_config.delete(
                ctx, code_signing_config_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.code_signing_config.delete code_signing_config_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="delete_code_signing_config",
        op_kwargs={"CodeSigningConfigArn": code_signing_config_arn},
    )


async def get(hub, ctx, code_signing_config_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified code signing configuration.

    Args:
        code_signing_config_arn(str): The The Amazon Resource Name (ARN) of the code signing configuration. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.code_signing_config.get(
                ctx, code_signing_config_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.code_signing_config.get code_signing_config_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="get_code_signing_config",
        op_kwargs={"CodeSigningConfigArn": code_signing_config_arn},
    )


async def list_all(hub, ctx, marker: str = None, max_items: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of code signing configurations. A request returns up to 10,000 configurations per call. You can use the MaxItems parameter to return fewer configurations per call.

    Args:
        marker(str, optional): Specify the pagination token that's returned by a previous request to retrieve the next page of results. Defaults to None.
        max_items(int, optional): Maximum number of items to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.code_signing_config.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.code_signing_config.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="list_code_signing_configs",
        op_kwargs={"Marker": marker, "MaxItems": max_items},
    )


async def update(
    hub,
    ctx,
    code_signing_config_arn: str,
    description: str = None,
    allowed_publishers: Dict = None,
    code_signing_policies: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update the code signing configuration. Changes to the code signing configuration take effect the next time a user tries to deploy a code package to the function.

    Args:
        code_signing_config_arn(str): The The Amazon Resource Name (ARN) of the code signing configuration.
        description(str, optional): Descriptive name for this code signing configuration. Defaults to None.
        allowed_publishers(Dict, optional): Signing profiles for this code signing configuration. Defaults to None.
        code_signing_policies(Dict, optional): The code signing policy. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.code_signing_config.update(
                ctx, code_signing_config_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.code_signing_config.update code_signing_config_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="update_code_signing_config",
        op_kwargs={
            "CodeSigningConfigArn": code_signing_config_arn,
            "Description": description,
            "AllowedPublishers": allowed_publishers,
            "CodeSigningPolicies": code_signing_policies,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def admin(hub, ctx, user_pool_id: str, username: str, group_name: str) -> None:
    r"""
    **Autogenerated function**

    Removes the specified user from the specified group. Calling this action requires developer credentials.

    Args:
        user_pool_id(str): The user pool ID for the user pool.
        username(str): The username for the user.
        group_name(str): The group name.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.remove_user_from_group.admin(
                ctx, user_pool_id=value, username=value, group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.remove_user_from_group.admin user_pool_id=value, username=value, group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="admin_remove_user_from_group",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "Username": username,
            "GroupName": group_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

     Returns the integration status of services that are integrated with DevOps Guru. The one service that can be integrated with DevOps Guru is AWS Systems Manager, which can be used to create an OpsItem for each generated insight.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.service_integration.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.service_integration.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="describe_service_integration",
        op_kwargs={},
    )


async def update(hub, ctx, service_integration: Dict) -> Dict:
    r"""
    **Autogenerated function**

     Enables or disables integration with a service that can be integrated with DevOps Guru. The one service that can be integrated with DevOps Guru is AWS Systems Manager, which can be used to create an OpsItem for each generated insight.

    Args:
        service_integration(Dict):  An IntegratedServiceConfig object used to specify the integrated service you want to update, and whether you want to update it to enabled or disabled. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.service_integration.update(
                ctx, service_integration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.service_integration.update service_integration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="update_service_integration",
        op_kwargs={"ServiceIntegration": service_integration},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create_multiple(
    hub,
    ctx,
    fsx_filesystem_arn: str,
    security_group_arns: List,
    user: str,
    password: str,
    subdirectory: str = None,
    tags: List = None,
    domain: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an endpoint for an Amazon FSx for Windows File Server file system.

    Args:
        subdirectory(str, optional): A subdirectory in the location’s path. This subdirectory in the Amazon FSx for Windows File Server file system is used to read data from the Amazon FSx for Windows File Server source location or write data to the FSx for Windows File Server destination. Defaults to None.
        fsx_filesystem_arn(str): The Amazon Resource Name (ARN) for the FSx for Windows File Server file system.
        security_group_arns(List): The Amazon Resource Names (ARNs) of the security groups that are to use to configure the FSx for Windows File Server file system.
        tags(List, optional): The key-value pair that represents a tag that you want to add to the resource. The value can be an empty string. This value helps you manage, filter, and search for your resources. We recommend that you create a name tag for your location. Defaults to None.
        user(str): The user who has the permissions to access files and folders in the FSx for Windows File Server file system. For information about choosing a user name that ensures sufficient permissions to files, folders, and metadata, see user.
        domain(str, optional): The name of the Windows domain that the FSx for Windows File Server belongs to. Defaults to None.
        password(str): The password of the user who has the permissions to access files and folders in the FSx for Windows File Server file system.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.fsx_window.create_multiple(
                ctx, fsx_filesystem_arn=value, security_group_arns=value, user=value, password=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.fsx_window.create_multiple fsx_filesystem_arn=value, security_group_arns=value, user=value, password=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="create_location_fsx_windows",
        op_kwargs={
            "Subdirectory": subdirectory,
            "FsxFilesystemArn": fsx_filesystem_arn,
            "SecurityGroupArns": security_group_arns,
            "Tags": tags,
            "User": user,
            "Domain": domain,
            "Password": password,
        },
    )


async def describe_all(hub, ctx, location_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata, such as the path information about an Amazon FSx for Windows File Server location.

    Args:
        location_arn(str): The Amazon Resource Name (ARN) of the FSx for Windows File Server location to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.fsx_window.describe_all(
                ctx, location_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.fsx_window.describe_all location_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="describe_location_fsx_windows",
        op_kwargs={"LocationArn": location_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, category_id: int, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all skills in the Alexa skill store by category.

    Args:
        category_id(int): The category ID for which the skills are being retrieved from the skill store.
        next_token(str, optional): The tokens used for pagination. Defaults to None.
        max_results(int, optional): The maximum number of skills returned per paginated calls. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.skill.store.skill_by_category.list(
                ctx, category_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.skill.store.skill_by_category.list category_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="list_skills_store_skills_by_category",
        op_kwargs={
            "CategoryId": category_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, direct_connect_gateway_name: str, amazon_side_asn: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Direct Connect gateway, which is an intermediate object that enables you to connect a set of virtual interfaces and virtual private gateways. A Direct Connect gateway is global and visible in any Region after it is created. The virtual interfaces and virtual private gateways that are connected through a Direct Connect gateway can be in different Regions. This enables you to connect to a VPC in any Region, regardless of the Region in which the virtual interfaces are located, and pass traffic between them.

    Args:
        direct_connect_gateway_name(str): The name of the Direct Connect gateway.
        amazon_side_asn(int, optional): The autonomous system number (ASN) for Border Gateway Protocol (BGP) to be configured on the Amazon side of the connection. The ASN must be in the private range of 64,512 to 65,534 or 4,200,000,000 to 4,294,967,294. The default is 64512. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.direct_connect_gateway.init.create(
                ctx, direct_connect_gateway_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.direct_connect_gateway.init.create direct_connect_gateway_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="create_direct_connect_gateway",
        op_kwargs={
            "directConnectGatewayName": direct_connect_gateway_name,
            "amazonSideAsn": amazon_side_asn,
        },
    )


async def delete(hub, ctx, direct_connect_gateway_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified Direct Connect gateway. You must first delete all virtual interfaces that are attached to the Direct Connect gateway and disassociate all virtual private gateways associated with the Direct Connect gateway.

    Args:
        direct_connect_gateway_id(str): The ID of the Direct Connect gateway.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.direct_connect_gateway.init.delete(
                ctx, direct_connect_gateway_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.direct_connect_gateway.init.delete direct_connect_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="delete_direct_connect_gateway",
        op_kwargs={"directConnectGatewayId": direct_connect_gateway_id},
    )


async def describe_all(
    hub,
    ctx,
    direct_connect_gateway_id: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all your Direct Connect gateways or only the specified Direct Connect gateway. Deleted Direct Connect gateways are not returned.

    Args:
        direct_connect_gateway_id(str, optional): The ID of the Direct Connect gateway. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. If MaxResults is given a value larger than 100, only 100 results are returned. Defaults to None.
        next_token(str, optional): The token provided in the previous call to retrieve the next page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.direct_connect_gateway.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.direct_connect_gateway.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="describe_direct_connect_gateways",
        op_kwargs={
            "directConnectGatewayId": direct_connect_gateway_id,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def logout(hub, ctx, access_token: str) -> None:
    r"""
    **Autogenerated function**

    Removes the client- and server-side session that is associated with the user.

    Args:
        access_token(str): The token issued by the CreateToken API call. For more information, see CreateToken in the AWS SSO OIDC API Reference Guide.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso.init.logout(ctx, access_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso.init.logout access_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso",
        operation="logout",
        op_kwargs={"accessToken": access_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    This action returns a list of the different Amazon EC2 Amazon Machine Images (AMIs) that are owned by your AWS account that would be supported for use on a Snow device. Currently, supported AMIs are based on the CentOS 7 (x86_64) - with Updates HVM, Ubuntu Server 14.04 LTS (HVM), and Ubuntu 16.04 LTS - Xenial (HVM) images, available on the AWS Marketplace.

    Args:
        max_results(int, optional): The maximum number of results for the list of compatible images. Currently, a Snowball Edge device can store 10 AMIs. Defaults to None.
        next_token(str, optional): HTTP requests are stateless. To identify what object comes "next" in the list of compatible images, you can specify a value for NextToken as the starting point for your list of returned images. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.compatible_image.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.compatible_image.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="list_compatible_images",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, application_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the migration status of an application.

    Args:
        application_id(str): The configurationId in Application Discovery Service that uniquely identifies the grouped application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.application_state.describe(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.application_state.describe application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="describe_application_state",
        op_kwargs={"ApplicationId": application_id},
    )


async def list_all(
    hub,
    ctx,
    application_ids: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the migration statuses for your applications. If you use the optional ApplicationIds parameter, only the migration statuses for those applications will be returned.

    Args:
        application_ids(List, optional): The configurationIds from the Application Discovery Service that uniquely identifies your applications. Defaults to None.
        next_token(str, optional): If a NextToken was returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in NextToken. Defaults to None.
        max_results(int, optional): Maximum number of results to be returned per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.application_state.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.application_state.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="list_application_states",
        op_kwargs={
            "ApplicationIds": application_ids,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def notify(
    hub,
    ctx,
    application_id: str,
    status: str,
    update_date_time: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sets the migration state of an application. For a given application identified by the value passed to ApplicationId, its status is set or updated by passing one of three values to Status: NOT_STARTED | IN_PROGRESS | COMPLETED.

    Args:
        application_id(str): The configurationId in Application Discovery Service that uniquely identifies the grouped application.
        status(str): Status of the application - Not Started, In-Progress, Complete.
        update_date_time(str, optional): The timestamp when the application state changed. Defaults to None.
        dry_run(bool, optional): Optional boolean flag to indicate whether any effect should take place. Used to test if the caller has permission to make the call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.application_state.notify(
                ctx, application_id=value, status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.application_state.notify application_id=value, status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="notify_application_state",
        op_kwargs={
            "ApplicationId": application_id,
            "Status": status,
            "UpdateDateTime": update_date_time,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    client_token: str,
    grant_arn: str,
    grant_name: str = None,
    allowed_operations: List = None,
    status: str = None,
    status_reason: str = None,
    source_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new version of the specified grant.

    Args:
        client_token(str): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
        grant_arn(str): Amazon Resource Name (ARN) of the grant.
        grant_name(str, optional): Grant name. Defaults to None.
        allowed_operations(List, optional): Allowed operations for the grant. Defaults to None.
        status(str, optional): Grant status. Defaults to None.
        status_reason(str, optional): . Defaults to None.
        source_version(str, optional): Current version of the grant. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.grant.version.create(
                ctx, client_token=value, grant_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.grant.version.create client_token=value, grant_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="create_grant_version",
        op_kwargs={
            "ClientToken": client_token,
            "GrantArn": grant_arn,
            "GrantName": grant_name,
            "AllowedOperations": allowed_operations,
            "Status": status,
            "StatusReason": status_reason,
            "SourceVersion": source_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, snapshot_copy_grant_name: str, kms_key_id: str = None, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a snapshot copy grant that permits Amazon Redshift to use a customer master key (CMK) from Key Management Service (KMS) to encrypt copied snapshots in a destination region.  For more information about managing snapshot copy grants, go to Amazon Redshift Database Encryption in the Amazon Redshift Cluster Management Guide.

    Args:
        snapshot_copy_grant_name(str): The name of the snapshot copy grant. This name must be unique in the region for the Amazon Web Services account. Constraints:   Must contain from 1 to 63 alphanumeric characters or hyphens.   Alphabetic characters must be lowercase.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.   Must be unique for all clusters within an Amazon Web Services account.  .
        kms_key_id(str, optional): The unique identifier of the customer master key (CMK) to which to grant Amazon Redshift permission. If no key is specified, the default key is used. Defaults to None.
        tags(List, optional): A list of tag instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.snapshot.copy.grant.create(
                ctx, snapshot_copy_grant_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.snapshot.copy.grant.create snapshot_copy_grant_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="create_snapshot_copy_grant",
        op_kwargs={
            "SnapshotCopyGrantName": snapshot_copy_grant_name,
            "KmsKeyId": kms_key_id,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, snapshot_copy_grant_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified snapshot copy grant.

    Args:
        snapshot_copy_grant_name(str): The name of the snapshot copy grant to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.snapshot.copy.grant.delete(
                ctx, snapshot_copy_grant_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.snapshot.copy.grant.delete snapshot_copy_grant_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_snapshot_copy_grant",
        op_kwargs={"SnapshotCopyGrantName": snapshot_copy_grant_name},
    )


async def describe_all(
    hub,
    ctx,
    snapshot_copy_grant_name: str = None,
    max_records: int = None,
    marker: str = None,
    tag_keys: List = None,
    tag_values: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of snapshot copy grants owned by the Amazon Web Services account in the destination region.  For more information about managing snapshot copy grants, go to Amazon Redshift Database Encryption in the Amazon Redshift Cluster Management Guide.

    Args:
        snapshot_copy_grant_name(str, optional): The name of the snapshot copy grant. Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeSnapshotCopyGrant request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request.  Constraints: You can specify either the SnapshotCopyGrantName parameter or the Marker parameter, but not both. . Defaults to None.
        tag_keys(List, optional): A tag key or keys for which you want to return all matching resources that are associated with the specified key or keys. For example, suppose that you have resources tagged with keys called owner and environment. If you specify both of these tag keys in the request, Amazon Redshift returns a response with all resources that have either or both of these tag keys associated with them. Defaults to None.
        tag_values(List, optional): A tag value or values for which you want to return all matching resources that are associated with the specified value or values. For example, suppose that you have resources tagged with values called admin and test. If you specify both of these tag values in the request, Amazon Redshift returns a response with all resources that have either or both of these tag values associated with them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.snapshot.copy.grant.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.snapshot.copy.grant.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_snapshot_copy_grants",
        op_kwargs={
            "SnapshotCopyGrantName": snapshot_copy_grant_name,
            "MaxRecords": max_records,
            "Marker": marker,
            "TagKeys": tag_keys,
            "TagValues": tag_values,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    This method is deprecated. Instead, use DisassociateFromAdministratorAccount. The Security Hub console continues to use DisassociateFromMasterAccount. It will eventually change to use DisassociateFromAdministratorAccount. Any IAM policies that specifically control access to this function must continue to use DisassociateFromMasterAccount. You should also add DisassociateFromAdministratorAccount to your policies to ensure that the correct permissions are in place after the console begins to use DisassociateFromAdministratorAccount. Disassociates the current Security Hub member account from the associated administrator account. This operation is only used by accounts that are not part of an organization. For organization accounts, only the administrator account can disassociate a member account.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.from_.master_account.disassociate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.from_.master_account.disassociate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="disassociate_from_master_account",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub,
    ctx,
    creator_request_id: str,
    firewall_rule_group_id: str,
    vpc_id: str,
    priority: int,
    name: str,
    mutation_protection: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a FirewallRuleGroup with a VPC, to provide DNS filtering for the VPC.

    Args:
        creator_request_id(str): A unique string that identifies the request and that allows failed requests to be retried without the risk of running the operation twice. CreatorRequestId can be any unique string, for example, a date/time stamp. .
        firewall_rule_group_id(str): The unique identifier of the firewall rule group. .
        vpc_id(str): The unique identifier of the VPC that you want to associate with the rule group. .
        priority(int): The setting that determines the processing order of the rule group among the rule groups that you associate with the specified VPC. DNS Firewall filters VPC traffic starting from the rule group with the lowest numeric priority setting.  You must specify a unique priority for each rule group that you associate with a single VPC. To make it easier to insert rule groups later, leave space between the numbers, for example, use 101, 200, and so on. You can change the priority setting for a rule group association after you create it. The allowed values for Priority are between 100 and 9900.
        name(str): A name that lets you identify the association, to manage and use it.
        mutation_protection(str, optional): If enabled, this setting disallows modification or removal of the association, to help prevent against accidentally altering DNS firewall protections. When you create the association, the default setting is DISABLED. . Defaults to None.
        tags(List, optional): A list of the tag keys and values that you want to associate with the rule group association. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.rule.group.init.associate(
                ctx,
                creator_request_id=value,
                firewall_rule_group_id=value,
                vpc_id=value,
                priority=value,
                name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.rule.group.init.associate creator_request_id=value, firewall_rule_group_id=value, vpc_id=value, priority=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="associate_firewall_rule_group",
        op_kwargs={
            "CreatorRequestId": creator_request_id,
            "FirewallRuleGroupId": firewall_rule_group_id,
            "VpcId": vpc_id,
            "Priority": priority,
            "Name": name,
            "MutationProtection": mutation_protection,
            "Tags": tags,
        },
    )


async def create(
    hub, ctx, creator_request_id: str, name: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an empty DNS Firewall rule group for filtering DNS network traffic in a VPC. You can add rules to the new rule group by calling CreateFirewallRule.

    Args:
        creator_request_id(str): A unique string defined by you to identify the request. This allows you to retry failed requests without the risk of running the operation twice. This can be any unique string, for example, a timestamp. .
        name(str): A name that lets you identify the rule group, to manage and use it.
        tags(List, optional): A list of the tag keys and values that you want to associate with the rule group. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.rule.group.init.create(
                ctx, creator_request_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.rule.group.init.create creator_request_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="create_firewall_rule_group",
        op_kwargs={"CreatorRequestId": creator_request_id, "Name": name, "Tags": tags},
    )


async def delete(hub, ctx, firewall_rule_group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified firewall rule group.

    Args:
        firewall_rule_group_id(str): The unique identifier of the firewall rule group that you want to delete. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.rule.group.init.delete(
                ctx, firewall_rule_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.rule.group.init.delete firewall_rule_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="delete_firewall_rule_group",
        op_kwargs={"FirewallRuleGroupId": firewall_rule_group_id},
    )


async def disassociate(hub, ctx, firewall_rule_group_association_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a FirewallRuleGroup from a VPC, to remove DNS filtering from the VPC.

    Args:
        firewall_rule_group_association_id(str): The identifier of the FirewallRuleGroupAssociation. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.rule.group.init.disassociate(
                ctx, firewall_rule_group_association_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.rule.group.init.disassociate firewall_rule_group_association_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="disassociate_firewall_rule_group",
        op_kwargs={
            "FirewallRuleGroupAssociationId": firewall_rule_group_association_id
        },
    )


async def get(hub, ctx, firewall_rule_group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the specified firewall rule group.

    Args:
        firewall_rule_group_id(str): The unique identifier of the firewall rule group. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.rule.group.init.get(
                ctx, firewall_rule_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.rule.group.init.get firewall_rule_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="get_firewall_rule_group",
        op_kwargs={"FirewallRuleGroupId": firewall_rule_group_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the minimal high-level information for the rule groups that you have defined.  A single call might return only a partial list of the rule groups. For information, see MaxResults.

    Args:
        max_results(int, optional): The maximum number of objects that you want Resolver to return for this request. If more objects are available, in the response, Resolver provides a NextToken value that you can use in a subsequent call to get the next batch of objects. If you don't specify a value for MaxResults, Resolver returns up to 100 objects. . Defaults to None.
        next_token(str, optional): For the first call to this list request, omit this value. When you request a list of objects, Resolver returns at most the number of objects specified in MaxResults. If more objects are available for retrieval, Resolver returns a NextToken value in the response. To retrieve the next batch of objects, use the token that was returned for the prior request in your next request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.rule.group.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.rule.group.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="list_firewall_rule_groups",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    mesh_name: str,
    spec: Dict,
    virtual_node_name: str,
    client_token: str = None,
    mesh_owner: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a virtual node within a service mesh.  A virtual node acts as a logical pointer to a particular task group, such as an Amazon ECS service or a Kubernetes deployment. When you create a virtual node, you can specify the service discovery information for your task group, and whether the proxy running in a task group will communicate with other proxies using Transport Layer Security (TLS). You define a listener for any inbound traffic that your virtual node expects. Any virtual service that your virtual node expects to communicate to is specified as a backend. The response metadata for your new virtual node contains the arn that is associated with the virtual node. Set this value to the full ARN; for example, arn:aws:appmesh:us-west-2:123456789012:myMesh/default/virtualNode/myApp) as the APPMESH_RESOURCE_ARN environment variable for your task group's Envoy proxy container in your task definition or pod spec. This is then mapped to the node.id and node.cluster Envoy parameters.  By default, App Mesh uses the name of the resource you specified in APPMESH_RESOURCE_ARN when Envoy is referring to itself in metrics and traces. You can override this behavior by setting the APPMESH_RESOURCE_CLUSTER environment variable with your own name.  For more information about virtual nodes, see Virtual nodes. You must be using 1.15.0 or later of the Envoy image when setting these variables. For more information aboutApp Mesh Envoy variables, see Envoy image in the AWS App Mesh User Guide.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Up to 36 letters, numbers, hyphens, and underscores are allowed. Defaults to None.
        mesh_name(str): The name of the service mesh to create the virtual node in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then the account that you specify must share the mesh with your account before you can create the resource in the service mesh. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        spec(Dict): The virtual node specification to apply.
        tags(List, optional): Optional metadata that you can apply to the virtual node to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you define. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters. Defaults to None.
        virtual_node_name(str): The name to use for the virtual node.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.virtual.node.create(
                ctx, mesh_name=value, spec=value, virtual_node_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.virtual.node.create mesh_name=value, spec=value, virtual_node_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="create_virtual_node",
        op_kwargs={
            "clientToken": client_token,
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "spec": spec,
            "tags": tags,
            "virtualNodeName": virtual_node_name,
        },
    )


async def delete(
    hub, ctx, mesh_name: str, virtual_node_name: str, mesh_owner: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing virtual node. You must delete any virtual services that list a virtual node as a service provider before you can delete the virtual node itself.

    Args:
        mesh_name(str): The name of the service mesh to delete the virtual node in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        virtual_node_name(str): The name of the virtual node to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.virtual.node.delete(
                ctx, mesh_name=value, virtual_node_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.virtual.node.delete mesh_name=value, virtual_node_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="delete_virtual_node",
        op_kwargs={
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "virtualNodeName": virtual_node_name,
        },
    )


async def describe(
    hub, ctx, mesh_name: str, virtual_node_name: str, mesh_owner: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes an existing virtual node.

    Args:
        mesh_name(str): The name of the service mesh that the virtual node resides in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        virtual_node_name(str): The name of the virtual node to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.virtual.node.describe(
                ctx, mesh_name=value, virtual_node_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.virtual.node.describe mesh_name=value, virtual_node_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="describe_virtual_node",
        op_kwargs={
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "virtualNodeName": virtual_node_name,
        },
    )


async def list_all(
    hub,
    ctx,
    mesh_name: str,
    limit: int = None,
    mesh_owner: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of existing virtual nodes.

    Args:
        limit(int, optional): The maximum number of results returned by ListVirtualNodes in paginated output. When you use this parameter, ListVirtualNodes returns only limit results in a single page along with a nextToken response element. You can see the remaining results of the initial request by sending another ListVirtualNodes request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, ListVirtualNodes returns up to 100 results and a nextToken value if applicable. Defaults to None.
        mesh_name(str): The name of the service mesh to list virtual nodes in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated ListVirtualNodes request where limit was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.virtual.node.list_all(ctx, mesh_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.virtual.node.list_all mesh_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="list_virtual_nodes",
        op_kwargs={
            "limit": limit,
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    mesh_name: str,
    spec: Dict,
    virtual_node_name: str,
    client_token: str = None,
    mesh_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing virtual node in a specified service mesh.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Up to 36 letters, numbers, hyphens, and underscores are allowed. Defaults to None.
        mesh_name(str): The name of the service mesh that the virtual node resides in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        spec(Dict): The new virtual node specification to apply. This overwrites the existing data.
        virtual_node_name(str): The name of the virtual node to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.virtual.node.update(
                ctx, mesh_name=value, spec=value, virtual_node_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.virtual.node.update mesh_name=value, spec=value, virtual_node_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="update_virtual_node",
        op_kwargs={
            "clientToken": client_token,
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "spec": spec,
            "virtualNodeName": virtual_node_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, gateway_arn: str, tape_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels archiving of a virtual tape to the virtual tape shelf (VTS) after the archiving process is initiated. This operation is only supported in the tape gateway type.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        tape_arn(str): The Amazon Resource Name (ARN) of the virtual tape you want to cancel archiving for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.archival.cancel(
                ctx, gateway_arn=value, tape_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.archival.cancel gateway_arn=value, tape_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="cancel_archival",
        op_kwargs={"GatewayARN": gateway_arn, "TapeARN": tape_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, hosted_zone_id: str, vpc: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Authorizes the account that created a specified VPC to submit an AssociateVPCWithHostedZone request to associate the VPC with a specified hosted zone that was created by a different account. To submit a CreateVPCAssociationAuthorization request, you must use the account that created the hosted zone. After you authorize the association, use the account that created the VPC to submit an AssociateVPCWithHostedZone request.  If you want to associate multiple VPCs that you created by using one account with a hosted zone that you created by using a different account, you must submit one authorization request for each VPC.

    Args:
        hosted_zone_id(str): The ID of the private hosted zone that you want to authorize associating a VPC with.
        vpc(Dict): A complex type that contains the VPC ID and region for the VPC that you want to authorize associating with your hosted zone.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.vpc.association_authorization.create(
                ctx, hosted_zone_id=value, vpc=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.vpc.association_authorization.create hosted_zone_id=value, vpc=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="create_vpc_association_authorization",
        op_kwargs={"HostedZoneId": hosted_zone_id, "VPC": vpc},
    )


async def delete(hub, ctx, hosted_zone_id: str, vpc: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Removes authorization to submit an AssociateVPCWithHostedZone request to associate a specified VPC with a hosted zone that was created by a different account. You must use the account that created the hosted zone to submit a DeleteVPCAssociationAuthorization request.  Sending this request only prevents the account that created the VPC from associating the VPC with the Amazon Route 53 hosted zone in the future. If the VPC is already associated with the hosted zone, DeleteVPCAssociationAuthorization won't disassociate the VPC from the hosted zone. If you want to delete an existing association, use DisassociateVPCFromHostedZone.

    Args:
        hosted_zone_id(str): When removing authorization to associate a VPC that was created by one account with a hosted zone that was created with a different account, the ID of the hosted zone.
        vpc(Dict): When removing authorization to associate a VPC that was created by one account with a hosted zone that was created with a different account, a complex type that includes the ID and region of the VPC.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.vpc.association_authorization.delete(
                ctx, hosted_zone_id=value, vpc=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.vpc.association_authorization.delete hosted_zone_id=value, vpc=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="delete_vpc_association_authorization",
        op_kwargs={"HostedZoneId": hosted_zone_id, "VPC": vpc},
    )


async def list_all(
    hub, ctx, hosted_zone_id: str, next_token: str = None, max_results: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the VPCs that were created by other accounts and that can be associated with a specified hosted zone because you've submitted one or more CreateVPCAssociationAuthorization requests.  The response includes a VPCs element with a VPC child element for each VPC that can be associated with the hosted zone.

    Args:
        hosted_zone_id(str): The ID of the hosted zone for which you want a list of VPCs that can be associated with the hosted zone.
        next_token(str, optional):  Optional: If a response includes a NextToken element, there are more VPCs that can be associated with the specified hosted zone. To get the next page of results, submit another request, and include the value of NextToken from the response in the nexttoken parameter in another ListVPCAssociationAuthorizations request. Defaults to None.
        max_results(str, optional):  Optional: An integer that specifies the maximum number of VPCs that you want Amazon Route 53 to return. If you don't specify a value for MaxResults, Route 53 returns up to 50 VPCs per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.vpc.association_authorization.list_all(
                ctx, hosted_zone_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.vpc.association_authorization.list_all hosted_zone_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="list_vpc_association_authorizations",
        op_kwargs={
            "HostedZoneId": hosted_zone_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )
